#ifndef CARD_H
#define CARD_H

#include "editstr.h"
#include "multied.h"

#define TITLE_WIDTH 40
#define BODY_WIDTH 40
#define BODY_HEIGHT 11

/* Logically would be 460 for 10 * (40 + 2) + 40, but it isn't. */
/* Microsoft says so. This results in UI weirdness. */
#define MAX_BODY_BYTES 450

#define SET_BOTH_TO_ZERO 0
#define SET_BODY_TO_TITLE 1
#define SET_TITLE_TO_BODY 2

struct card
{
    struct card *prev, *next;

    struct EditString *title;
    struct MultiEdit *body;

    /* OLE object or graphic bitmap skipped */
    int object_skipped;

    /* refers to whether out-of-date from disk */
    int dirty;
};

/* Returns allocated card or NULL */
struct card *alloc_blank_card (void);

/* Returns success */
int duplicate_card (struct card *card);

/* Returns next card, or previous card if no next card, or NULL */
struct card *delete_card (struct card *card);

/* Pass in '\n' to insert newline, returns success, sets dirty fields */
int insert_body_char (struct card *card, char ch);
int insert_title_char (struct card *card, char ch);

/* Returns success, sets dirty fields */
int delete_body_at (struct card *card);
int delete_body_prev (struct card *card);
int delete_title_at (struct card *card);
int delete_title_prev (struct card *card);

/* Returns success */
int get_row (struct card *card, char *buffer, int *row_len, int row);

void reset_cursor_pos (struct card *card, int which);

#endif /* CARD_H */
